@@ -4,7 +4,6 @@ from typing import List
 import arrow
 
 from canvas_workflow_kit import events
-from canvas_workflow_kit.builtin_cqms.diabetes_quality_measure import DiabetesQualityMeasure
 from canvas_workflow_kit.protocol import (
     STATUS_DUE,
     STATUS_SATISFIED,
@@ -26,6 +25,7 @@ from canvas_workflow_kit.value_set.v2018 import (
     Proteinuria,
     UrineProteinTests
 )
+from .diabetes_quality_measure import DiabetesQualityMeasure
 
 
 class ClinicalQualityMeasure134v6(DiabetesQualityMeasure):
