@@ -28,11 +28,11 @@ class CustomerScanDementiaAssessment(ExternallyAwareClinicalQualityMeasure,
     A clinical quality measure (which is a type of protocol) for the customer SCAN.
     More information at https://docs.google.com/document/d/1NW4b3OT_yPeZy_oIKt_DCCeQ0egDaWFE/edit
     """
-    class Meta:
 
+    class Meta:
         title = 'SCAN: Dementia Assessment'
         version = '2020-10-13v1'
-        description = 'A clinical quality measure (which is a type of protocol) for the customer SCAN.'
+        description = 'A clinical quality measure (which is a type of protocol) for the customer SCAN.'  # noqa: E501
         information = 'https://docs.google.com/document/d/1NW4b3OT_yPeZy_oIKt_DCCeQ0egDaWFE/edit'
 
         identifiers = ['CustomerScanDementiaAssessmentV1']
