@@ -10,6 +10,7 @@ from canvas_workflow_kit.patient_recordset import (
     ConditionRecordSet,
     ImagingReportRecordSet,
     ImmunizationRecordSet,
+    InpatientStayRecordSet,
     InstructionRecordSet,
     InterviewRecordSet,
     LabReportRecordSet,
@@ -39,6 +40,7 @@ class Patient:
         ConditionRecordSet,
         ImagingReportRecordSet,
         ImmunizationRecordSet,
+        InpatientStayRecordSet,
         InstructionRecordSet,
         InterviewRecordSet,
         LabReportRecordSet,
@@ -87,10 +89,15 @@ class Patient:
         self.referrals = ReferralRecordSet.new_from(
             data.get(ReferralRecordSet.API_UPDATE_FIELD, []))
 
+        self.inpatient_stays = InpatientStayRecordSet.new_from(
+            data.get(InpatientStayRecordSet.API_UPDATE_FIELD, []))
+
         self.suspect_hccs = data.get('suspectHccs', [])
 
         self.upcoming_appointments = data.get('upcomingAppointments', [])
 
+        self.upcoming_appointment_notes = data.get('upcomingAppointmentNotes', [])
+
         self.vital_signs = VitalSignRecordSet.new_from(
             data.get(VitalSignRecordSet.API_UPDATE_FIELD, []))
 
