@@ -1,4 +1,4 @@
-from .medications import *
+from .medication import *
 from .diagnosis import *
 from .encounter_performed import *
 from .encounter import *
@@ -9,10 +9,10 @@ from .procedure_performed import *
 from .procedure import *
 from .device import *
 from .communication import *
-from .immunizations import *
+from .immunization import *
 from .allergy import *
 from .patient_characteristic import *
 from .rationale import *
 from .other import *
 from .assessment import *
-from .result import *
\ No newline at end of file
+from .result import *
